timesignaturetools.time_signature_to_binary_time_signature
==========================================================

.. autofunction:: abjad.tools.timesignaturetools.time_signature_to_binary_time_signature.time_signature_to_binary_time_signature
